\name{nltk_pos_tag}
\alias{nltk_pos_tag}
\alias{nltk_batch_pos_tag}
\alias{nltk_untag}

\title{NLTK Taggers}
\description{
  The part-of-speech tagger, or POS tagger, presented below processes a
  sequence of words, and attaches a part of speech tag to each
  word. The functions call NLTK's currently recommended POS tagger to
  tag the given list of tokens (currently
  \code{'taggers/maxent_treebank_pos_tagger/english.pickle'}.
}
\usage{
nltk_pos_tag( tokens )
nltk_batch_pos_tag( sents )
nltk_untag( token_tag_pairs )
}
\arguments{
  \item{tokens}{A character vector representing tokens of a
    sentence as returned by \code{\link{nltk_word_tokenize}}.}
  \item{sents}{A list of character vectors. Each element contains
    tokens of a sentence (see above).}
  \item{ token_tag_pairs}{A list of token/tag pairs as returned by
    \code{nltk_pos_tag()}.}
}
\value{
  A (nested) list of token/tag pairs.
}
\references{
  \url{http://nltk.googlecode.com/svn/trunk/doc/api/nltk.tag-module.html}
  \url{http://nltk.googlecode.com/svn/trunk/doc/book/ch05.html}
}
\examples{
## taken from Section 5.1 of the NLTK book
## see http://nltk.googlecode.com/svn/trunk/doc/book/ch05.html
text <- nltk_word_tokenize("And now for something completely different")
text
tagged <- nltk_pos_tag( text )
tagged
nltk_untag( tagged )
sents <- c( "And now for something completely different",
            "They refuse to permit us to obtain the refuse permit" )

nltk_batch_pos_tag( lapply(sents, nltk_word_tokenize) )
}

